@@ -2,10 +2,8 @@
 # this repository contains the full copyright notices and license terms.
 
 from trytond.pool import Pool
-from . import account
-from . import sale
-from . import purchase
-from . import stock
+
+from . import account, purchase, sale
 
 
 def register():
@@ -28,7 +26,3 @@ def register():
         purchase.Line,
         module='account_tax_rule_country', type_='model',
         depends=['purchase'])
-    Pool.register(
-        stock.Move,
-        module='account_tax_rule_country', type_='model',
-        depends=['stock'])
